responsive_adaptive_ui library
Classes
- AdaptiveButton
- A button that adapts its style based on the platform.
- Responsive
- A utility class for responsive sizing and spacing.
- ResponsiveBuilder
- A builder that helps adapt the UI to different screen sizes.
- ResponsiveText
- A text widget that automatically adapts font size between a minimum and maximum range depending on screen width.
Enums
- DeviceType
- Represents different device types for responsive UI.